@@ -664,7 +664,7 @@ Returns t if checkout was successful, nil otherwise."
     ))
 
 ;;; Emacs 19 menus.
-(if (not vc-elucidated)
+(if (and (not vc-elucidated) (boundp 'menu-bar-final-items))
     (progn
       (defvar menu-bar-vc-menu
         (make-sparse-keymap "VC"))
